define({ root:

//begin v1.x content
{
	"field-dayperiod-narrow@localeAlias287": {
		"bundle": "",
		"target": "field-dayperiod-short"
	},
	"field-dayperiod-narrow@localeAlias288": {
		"bundle": "",
		"target": "field-dayperiod"
	},
	"quarters-standAlone-abbr@localeAlias220": {
		"bundle": "gregorian",
		"target": "quarters-format-wide"
	},
	"field-thu-narrow-relative+0": "this Thursday",
	"dayPeriods-standAlone-wide@localeAlias228": {
		"bundle": "gregorian",
		"target": "dayPeriods-standAlone-abbr"
	},
	"field-thu-narrow-relative+1": "next Thursday",
	"dayPeriods-standAlone-wide@localeAlias229": {
		"bundle": "gregorian",
		"target": "dayPeriods-format-abbr"
	},
	"field-weekOfMonth-narrow@localeAlias251": {
		"bundle": "",
		"target": "field-weekOfMonth-short"
	},
	"field-weekOfMonth-narrow@localeAlias252": {
		"bundle": "",
		"target": "field-weekOfMonth"
	},
	"field-sun-narrow-relative+0": "this Sunday",
	"field-sun-narrow-relative+1": "next Sunday",
	"months-format-wide": [
		"Tout",
		"Baba",
		"Hator",
		"Kiahk",
		"Toba",
		"Amshir",
		"Baramhat",
		"Baramouda",
		"Bashans",
		"Paona",
		"Epep",
		"Mesra",
		"Nasie"
	],
	"days@localeAlias205": {
		"bundle": "gregorian",
		"target": "days"
	},
	"dayPeriods-standAlone-abbr-pm": "PM",
	"dateFormatItem-Hms": "HH:mm:ss",
	"field-fri-narrow-relative+0": "this Friday",
	"eraNarrow": [
		"ERA0",
		"ERA1"
	],
	"field-fri-narrow-relative+1": "next Friday",
	"field-dayperiod-short@localeAlias286": {
		"bundle": "",
		"target": "field-dayperiod"
	},
	"days-standAlone-narrow": [
		"S",
		"M",
		"T",
		"W",
		"T",
		"F",
		"S"
	],
	"days-standAlone-wide": [
		"Sun",
		"Mon",
		"Tue",
		"Wed",
		"Thu",
		"Fri",
		"Sat"
	],
	"field-week-short@localeAlias247": {
		"bundle": "",
		"target": "field-week"
	},
	"dateFormatItem-Ehm": "E h:mm a",
	"dateTimeFormats-appendItem-Timezone": "{0} {1}",
	"field-wed-narrow-relative+-1": "last Wednesday",
	"field-minute-narrow-relative+0": "this minute",
	"days-format-wide": [
		"Sun",
		"Mon",
		"Tue",
		"Wed",
		"Thu",
		"Fri",
		"Sat"
	],
	"quarters-format-abbr@localeAlias217": {
		"bundle": "gregorian",
		"target": "quarters-format-wide"
	},
	"field-month-short-relative+0": "this month",
	"field-month-short-relative+1": "next month",
	"dateFormatItem-Ehms": "E h:mm:ss a",
	"field-thu-relative+0": "this Thursday",
	"field-fri-narrow@localeAlias281": {
		"bundle": "",
		"target": "field-fri-short"
	},
	"dayPeriods-format-wide-am": "AM",
	"field-thu-relative+1": "next Thursday",
	"field-fri-narrow@localeAlias282": {
		"bundle": "",
		"target": "field-fri"
	},
	"field-fri-relative+0": "this Friday",
	"field-fri-relative+1": "next Friday",
	"field-quarter-relative+0": "this quarter",
	"field-thu-narrow-relative+-1": "last Thursday",
	"field-quarter-relative+1": "next quarter",
	"field-sun-short-relative+0": "this Sunday",
	"timeFormat-short": "HH:mm",
	"field-sun-short-relative+1": "next Sunday",
	"dateFormatItem-hms": "h:mm:ss a",
	"dateFormatItem-Md": "MM-dd",
	"field-week-narrow": "Week",
	"field-hour-relative+0": "this hour",
	"field-day-relative+-1": "yesterday",
	"field-mon-narrow-relative+-1": "last Monday",
	"field-minute-narrow": "Minute",
	"dateFormatItem-yyyyMMM": "G y MMM",
	"field-thu-short-relative+0": "this Thursday",
	"field-mon-relative+0": "this Monday",
	"field-thu-short-relative+1": "next Thursday",
	"field-mon-relative+1": "next Monday",
	"dateTimeFormats-appendItem-Era": "{1} {0}",
	"field-day-narrow-relative+0": "today",
	"field-era-short": "Era",
	"field-day-narrow-relative+1": "tomorrow",
	"dateFormat@localeAlias232": {
		"bundle": "generic",
		"target": "dateFormat"
	},
	"field-sat-narrow-relative+0": "this Saturday",
	"timeFormat-long": "HH:mm:ss z",
	"field-sat-narrow-relative+1": "next Saturday",
	"field-minute-narrow@localeAlias293": {
		"bundle": "",
		"target": "field-minute-short"
	},
	"field-minute-narrow@localeAlias294": {
		"bundle": "",
		"target": "field-minute"
	},
	"field-week-narrow-relative+0": "this week",
	"field-week-narrow-relative+1": "next week",
	"field-hour-short-relative+0": "this hour",
	"field-wed-narrow-relative+0": "this Wednesday",
	"field-wed-narrow-relative+1": "next Wednesday",
	"field-sun-short@localeAlias265": {
		"bundle": "",
		"target": "field-sun"
	},
	"field-quarter-short@localeAlias241": {
		"bundle": "",
		"target": "field-quarter"
	},
	"field-month": "Month",
	"months-standAlone-wide": [
		"Tout",
		"Baba",
		"Hator",
		"Kiahk",
		"Toba",
		"Amshir",
		"Baramhat",
		"Baramouda",
		"Bashans",
		"Paona",
		"Epep",
		"Mesra",
		"Nasie"
	],
	"dateTimeFormats-appendItem-Second": "{0} ({2}: {1})",
	"field-weekday-narrow": "Day of the Week",
	"field-year-relative+0": "this year",
	"field-year-relative+1": "next year",
	"dayPeriods-format-wide@localeAlias224": {
		"bundle": "gregorian",
		"target": "dayPeriods-format-abbr"
	},
	"field-tue-relative+0": "this Tuesday",
	"field-tue-relative+1": "next Tuesday",
	"field-dayOfYear-short@localeAlias256": {
		"bundle": "",
		"target": "field-dayOfYear"
	},
	"field-minute-short-relative+0": "this minute",
	"dateFormatItem-hm": "h:mm a",
	"field-year-narrow": "Year",
	"field-quarter-narrow@localeAlias242": {
		"bundle": "",
		"target": "field-quarter-short"
	},
	"field-quarter-narrow@localeAlias243": {
		"bundle": "",
		"target": "field-quarter"
	},
	"dateTimeFormats-appendItem-Day": "{0} ({2}: {1})",
	"field-tue-short-relative+0": "this Tuesday",
	"field-tue-short-relative+1": "next Tuesday",
	"dateTimeFormats-appendItem-Year": "{1} {0}",
	"dateTimeFormats-appendItem-Day-Of-Week": "{0} {1}",
	"field-tue-narrow-relative+0": "this Tuesday",
	"field-tue-narrow-relative+1": "next Tuesday",
	"dateTimeFormat-full": "{1} {0}",
	"dateFormatItem-E": "ccc",
	"dateFormatItem-EBhm": "E h:mm B",
	"dateFormatItem-H": "HH",
	"field-wed-relative+0": "this Wednesday",
	"field-wed-relative+1": "next Wednesday",
	"dateFormatItem-M": "L",
	"field-wed-short-relative+0": "this Wednesday",
	"field-wed-short-relative+1": "next Wednesday",
	"field-fri-short-relative+0": "this Friday",
	"field-weekOfMonth-short": "Week Of Month",
	"field-fri-short-relative+1": "next Friday",
	"field-weekdayOfMonth-narrow@localeAlias263": {
		"bundle": "",
		"target": "field-weekdayOfMonth-short"
	},
	"field-wed-narrow@localeAlias275": {
		"bundle": "",
		"target": "field-wed-short"
	},
	"field-weekdayOfMonth-narrow@localeAlias264": {
		"bundle": "",
		"target": "field-weekdayOfMonth"
	},
	"field-wed-narrow@localeAlias276": {
		"bundle": "",
		"target": "field-wed"
	},
	"field-quarter-short-relative+-1": "last quarter",
	"field-thu-short@localeAlias277": {
		"bundle": "",
		"target": "field-thu"
	},
	"field-year-short-relative+-1": "last year",
	"days-standAlone-abbr@localeAlias210": {
		"bundle": "gregorian",
		"target": "days-format-abbr"
	},
	"dateFormatItem-Bhm": "h:mm B",
	"days-standAlone-abbr@localeAlias211": {
		"bundle": "gregorian",
		"target": "days-format-wide"
	},
	"dateTimeFormats-appendItem-Hour": "{0} ({2}: {1})",
	"dateTimeFormat-medium": "{1} {0}",
	"field-quarter-narrow-relative+-1": "last quarter",
	"dateFormatItem-d": "d",
	"field-weekdayOfMonth-short@localeAlias262": {
		"bundle": "",
		"target": "field-weekdayOfMonth"
	},
	"dayPeriods-format-abbr-pm": "PM",
	"dateFormatItem-h": "h a",
	"quarters-standAlone-wide": [
		"Q1",
		"Q2",
		"Q3",
		"Q4"
	],
	"field-tue-short@localeAlias271": {
		"bundle": "",
		"target": "field-tue"
	},
	"field-weekOfMonth-narrow": "Week Of Month",
	"quarters@localeAlias216": {
		"bundle": "gregorian",
		"target": "quarters"
	},
	"field-day-narrow@localeAlias254": {
		"bundle": "",
		"target": "field-day-short"
	},
	"field-day-narrow@localeAlias255": {
		"bundle": "",
		"target": "field-day"
	},
	"dateFormatItem-yyyyQQQ": "G y QQQ",
	"field-minute-short@localeAlias292": {
		"bundle": "",
		"target": "field-minute"
	},
	"dateFormatItem-yyyyMMMM": "G y MMMM",
	"dateFormatItem-y": "G y",
	"field-minute-relative+0": "this minute",
	"field-year-short-relative+0": "this year",
	"dateFormatItem-EBhms": "E h:mm:ss B",
	"field-year-short-relative+1": "next year",
	"field-weekday": "Day of the Week",
	"dayPeriods-format-narrow-pm": "PM",
	"dateTimeFormats-appendItem-Quarter": "{0} ({2}: {1})",
	"field-tue-narrow-relative+-1": "last Tuesday",
	"dayPeriods-standAlone-narrow@localeAlias226": {
		"bundle": "gregorian",
		"target": "dayPeriods-standAlone-abbr"
	},
	"dayPeriods-standAlone-narrow@localeAlias227": {
		"bundle": "gregorian",
		"target": "dayPeriods-format-abbr"
	},
	"field-year-narrow-relative+-1": "last year",
	"dateFormatItem-yyyyMMMd": "G y MMM d",
	"field-sat-relative+-1": "last Saturday",
	"dayPeriods-standAlone-narrow-pm": "PM",
	"field-mon-narrow-relative+0": "this Monday",
	"field-mon-narrow-relative+1": "next Monday",
	"field-sat-narrow@localeAlias284": {
		"bundle": "",
		"target": "field-sat-short"
	},
	"days-format-short@localeAlias208": {
		"bundle": "gregorian",
		"target": "days-format-abbr"
	},
	"field-sat-narrow@localeAlias285": {
		"bundle": "",
		"target": "field-sat"
	},
	"days-format-short@localeAlias209": {
		"bundle": "gregorian",
		"target": "days-format-wide"
	},
	"field-second": "Second",
	"field-year-relative+-1": "last year",
	"field-weekdayOfMonth-short": "Weekday Of Month",
	"dateFormat-short": "GGGGG y-MM-dd",
	"eraNames": [
		"ERA0",
		"ERA1"
	],
	"field-second-short": "Second",
	"field-thu-short-relative+-1": "last Thursday",
	"field-zone": "Zone",
	"field-dayperiod-narrow": "Dayperiod",
	"field-sun-short-relative+-1": "last Sunday",
	"eraNames@localeAlias230": {
		"bundle": "coptic",
		"target": "eraAbbr"
	},
	"eraAbbr": [
		"ERA0",
		"ERA1"
	],
	"field-week-short": "Week",
	"dayPeriods-standAlone-abbr-am": "AM",
	"dayPeriods-standAlone-wide-pm": "PM",
	"field-year-short@localeAlias238": {
		"bundle": "",
		"target": "field-year"
	},
	"dateFormatItem-ms": "mm:ss",
	"field-day-relative+0": "today",
	"field-day-relative+1": "tomorrow",
	"field-zone-narrow@localeAlias300": {
		"bundle": "",
		"target": "field-zone"
	},
	"field-mon-short@localeAlias268": {
		"bundle": "",
		"target": "field-mon"
	},
	"dayPeriods-format-narrow@localeAlias223": {
		"bundle": "gregorian",
		"target": "dayPeriods-format-abbr"
	},
	"field-day-short-relative+0": "today",
	"field-dayOfYear-short": "Day Of Year",
	"field-era-short@localeAlias235": {
		"bundle": "",
		"target": "field-era"
	},
	"field-day-short-relative+1": "tomorrow",
	"dateFormat-long": "G y MMMM d",
	"field-sun-narrow-relative+-1": "last Sunday",
	"field-second-relative+0": "now",
	"field-quarter-relative+-1": "last quarter",
	"dayPeriods-standAlone-abbr@localeAlias225": {
		"bundle": "gregorian",
		"target": "dayPeriods-format-abbr"
	},
	"quarters-format-abbr": [
		"Q1",
		"Q2",
		"Q3",
		"Q4"
	],
	"months-standAlone-abbr@localeAlias202": {
		"bundle": "coptic",
		"target": "months-format-abbr"
	},
	"timeFormat@localeAlias233": {
		"bundle": "gregorian",
		"target": "timeFormat"
	},
	"months-standAlone-abbr@localeAlias203": {
		"bundle": "coptic",
		"target": "months-format-wide"
	},
	"days-standAlone-wide@localeAlias215": {
		"bundle": "gregorian",
		"target": "days-format-wide"
	},
	"field-week-relative+-1": "last week",
	"field-month-relative+-1": "last month",
	"quarters-standAlone-wide@localeAlias221": {
		"bundle": "gregorian",
		"target": "quarters-format-wide"
	},
	"months-format-narrow": [
		"1",
		"2",
		"3",
		"4",
		"5",
		"6",
		"7",
		"8",
		"9",
		"10",
		"11",
		"12",
		"13"
	],
	"field-year": "Year",
	"field-era": "Era",
	"dateTime@localeAlias234": {
		"bundle": "generic",
		"target": "dateTime"
	},
	"days-standAlone-short": [
		"Sun",
		"Mon",
		"Tue",
		"Wed",
		"Thu",
		"Fri",
		"Sat"
	],
	"field-second-short@localeAlias295": {
		"bundle": "",
		"target": "field-second"
	},
	"quarters-format-narrow": [
		"1",
		"2",
		"3",
		"4"
	],
	"field-tue-narrow@localeAlias272": {
		"bundle": "",
		"target": "field-tue-short"
	},
	"field-tue-narrow@localeAlias273": {
		"bundle": "",
		"target": "field-tue"
	},
	"field-day-short-relative+-1": "yesterday",
	"dateFormatItem-GyMMM": "G y MMM",
	"timeFormat-full": "HH:mm:ss zzzz",
	"dateFormatItem-Bhms": "h:mm:ss B",
	"field-zone-narrow@localeAlias299": {
		"bundle": "",
		"target": "field-zone-short"
	},
	"field-wed-short@localeAlias274": {
		"bundle": "",
		"target": "field-wed"
	},
	"field-hour": "Hour",
	"field-second-narrow@localeAlias296": {
		"bundle": "",
		"target": "field-second-short"
	},
	"field-second-narrow@localeAlias297": {
		"bundle": "",
		"target": "field-second"
	},
	"field-dayOfYear-narrow": "Day Of Year",
	"field-second-narrow-relative+0": "now",
	"field-quarter": "Quarter",
	"field-month-narrow-relative+0": "this month",
	"quarters-format-narrow@localeAlias218": {
		"bundle": "gregorian",
		"target": "quarters-standAlone-narrow"
	},
	"field-month-narrow-relative+1": "next month",
	"field-year-narrow@localeAlias239": {
		"bundle": "",
		"target": "field-year-short"
	},
	"dateFormatItem-yyyy": "G y",
	"field-hour-short@localeAlias289": {
		"bundle": "",
		"target": "field-hour"
	},
	"dateTimeFormats-appendItem-Minute": "{0} ({2}: {1})",
	"field-day": "Day",
	"field-mon-relative+-1": "last Monday",
	"field-zone-short@localeAlias298": {
		"bundle": "",
		"target": "field-zone"
	},
	"field-year-narrow@localeAlias240": {
		"bundle": "",
		"target": "field-year"
	},
	"field-dayOfYear": "Day Of Year",
	"dateFormat-medium": "G y MMM d",
	"days-standAlone-short@localeAlias212": {
		"bundle": "gregorian",
		"target": "days-format-short"
	},
	"field-month-narrow@localeAlias245": {
		"bundle": "",
		"target": "field-month-short"
	},
	"days-standAlone-short@localeAlias213": {
		"bundle": "gregorian",
		"target": "days-format-abbr"
	},
	"dateTimeFormat-short": "{1} {0}",
	"field-month-narrow@localeAlias246": {
		"bundle": "",
		"target": "field-month"
	},
	"days-standAlone-short@localeAlias214": {
		"bundle": "gregorian",
		"target": "days-format-wide"
	},
	"dateFormatItem-GyMMMd": "G y MMM d",
	"dateFormatItem-MEd": "MM-dd, E",
	"field-tue-short-relative+-1": "last Tuesday",
	"field-year-short": "Year",
	"field-month-short": "Month",
	"dateFormatItem-MMMEd": "MMM d, E",
	"dateFormatItem-MMMd": "MMM d",
	"field-weekOfMonth-short@localeAlias250": {
		"bundle": "",
		"target": "field-weekOfMonth"
	},
	"dateFormatItem-Bh": "h B",
	"months-format-abbr": [
		"Tout",
		"Baba",
		"Hator",
		"Kiahk",
		"Toba",
		"Amshir",
		"Baramhat",
		"Baramouda",
		"Bashans",
		"Paona",
		"Epep",
		"Mesra",
		"Nasie"
	],
	"dayPeriods-format-abbr-am": "AM",
	"field-sat-relative+0": "this Saturday",
	"dayPeriods-format-wide-pm": "PM",
	"field-sat-relative+1": "next Saturday",
	"field-sat-short@localeAlias283": {
		"bundle": "",
		"target": "field-sat"
	},
	"days-format-abbr@localeAlias206": {
		"bundle": "gregorian",
		"target": "days-format-wide"
	},
	"months-standAlone-wide@localeAlias204": {
		"bundle": "coptic",
		"target": "months-format-wide"
	},
	"days-standAlone-abbr": [
		"Sun",
		"Mon",
		"Tue",
		"Wed",
		"Thu",
		"Fri",
		"Sat"
	],
	"field-zone-short": "Zone",
	"field-week-short-relative+0": "this week",
	"field-week-short-relative+1": "next week",
	"dateFormatItem-yyyyMMMEd": "G y MMM d, E",
	"dateTimeFormats-appendItem-Week": "{0} ({2}: {1})",
	"field-fri-short-relative+-1": "last Friday",
	"field-month-narrow": "Month",
	"dayPeriods-format-narrow-am": "AM",
	"field-month-narrow-relative+-1": "last month",
	"days-format-abbr": [
		"Sun",
		"Mon",
		"Tue",
		"Wed",
		"Thu",
		"Fri",
		"Sat"
	],
	"field-weekday-short": "Day of the Week",
	"field-day-narrow-relative+-1": "yesterday",
	"field-quarter-short": "Quarter",
	"days-format-short": [
		"Sun",
		"Mon",
		"Tue",
		"Wed",
		"Thu",
		"Fri",
		"Sat"
	],
	"months-standAlone-narrow": [
		"1",
		"2",
		"3",
		"4",
		"5",
		"6",
		"7",
		"8",
		"9",
		"10",
		"11",
		"12",
		"13"
	],
	"field-day-short@localeAlias253": {
		"bundle": "",
		"target": "field-day"
	},
	"days-format-narrow": [
		"S",
		"M",
		"T",
		"W",
		"T",
		"F",
		"S"
	],
	"dateFormatItem-EHm": "E HH:mm",
	"field-month-short@localeAlias244": {
		"bundle": "",
		"target": "field-month"
	},
	"field-quarter-narrow": "Quarter",
	"field-mon-short-relative+0": "this Monday",
	"field-mon-short-relative+1": "next Monday",
	"months-format-abbr@localeAlias200": {
		"bundle": "coptic",
		"target": "months-format-wide"
	},
	"field-dayperiod-short": "Dayperiod",
	"dayPeriods-standAlone-narrow-am": "AM",
	"field-week-narrow-relative+-1": "last week",
	"days-format-narrow@localeAlias207": {
		"bundle": "gregorian",
		"target": "days-standAlone-narrow"
	},
	"field-thu-relative+-1": "last Thursday",
	"field-mon-short-relative+-1": "last Monday",
	"field-fri-narrow-relative+-1": "last Friday",
	"timeFormat-medium": "HH:mm:ss",
	"field-dayOfYear-narrow@localeAlias257": {
		"bundle": "",
		"target": "field-dayOfYear-short"
	},
	"field-weekday-short@localeAlias259": {
		"bundle": "",
		"target": "field-weekday"
	},
	"field-dayOfYear-narrow@localeAlias258": {
		"bundle": "",
		"target": "field-dayOfYear"
	},
	"field-quarter-short-relative+0": "this quarter",
	"field-mon-narrow@localeAlias269": {
		"bundle": "",
		"target": "field-mon-short"
	},
	"field-quarter-short-relative+1": "next quarter",
	"dateFormatItem-Ed": "d, E",
	"field-wed-relative+-1": "last Wednesday",
	"field-weekOfMonth": "Week Of Month",
	"field-weekdayOfMonth-narrow": "Weekday Of Month",
	"dayPeriods-standAlone-wide-am": "AM",
	"field-fri-relative+-1": "last Friday",
	"field-mon-narrow@localeAlias270": {
		"bundle": "",
		"target": "field-mon"
	},
	"field-sun-narrow@localeAlias266": {
		"bundle": "",
		"target": "field-sun-short"
	},
	"field-sun-narrow@localeAlias267": {
		"bundle": "",
		"target": "field-sun"
	},
	"field-minute": "Minute",
	"quarters-standAlone-narrow": [
		"1",
		"2",
		"3",
		"4"
	],
	"field-second-short-relative+0": "now",
	"quarters-format-wide": [
		"Q1",
		"Q2",
		"Q3",
		"Q4"
	],
	"field-day-short": "Day",
	"field-dayperiod": "Dayperiod",
	"field-hour-short": "Hour",
	"months-standAlone-abbr": [
		"Tout",
		"Baba",
		"Hator",
		"Kiahk",
		"Toba",
		"Amshir",
		"Baramhat",
		"Baramouda",
		"Bashans",
		"Paona",
		"Epep",
		"Mesra",
		"Nasie"
	],
	"field-month-relative+0": "this month",
	"field-second-narrow": "Second",
	"field-month-relative+1": "next month",
	"dateFormat-full": "G y MMMM d, EEEE",
	"dateFormatItem-yyyyMEd": "GGGGG y-MM-dd, E",
	"field-era-narrow": "Era",
	"field-sat-short-relative+-1": "last Saturday",
	"dayPeriods@localeAlias222": {
		"bundle": "gregorian",
		"target": "dayPeriods"
	},
	"field-week-short-relative+-1": "last week",
	"dateTimeFormat-long": "{1} {0}",
	"field-sun-relative+-1": "last Sunday",
	"field-wed-short-relative+-1": "last Wednesday",
	"dateFormatItem-yyyyQQQQ": "G y QQQQ",
	"field-weekdayOfMonth": "Weekday Of Month",
	"dateFormatItem-yyyyMd": "GGGGG y-MM-dd",
	"field-quarter-narrow-relative+0": "this quarter",
	"dateFormatItem-GyMMMEd": "G y MMM d, E",
	"field-quarter-narrow-relative+1": "next quarter",
	"field-sat-short-relative+0": "this Saturday",
	"field-sat-short-relative+1": "next Saturday",
	"field-hour-narrow": "Hour",
	"field-year-narrow-relative+0": "this year",
	"field-year-narrow-relative+1": "next year",
	"dateFormatItem-Gy": "G y",
	"field-zone-narrow": "Zone",
	"dateFormatItem-yyyyM": "GGGGG y-MM",
	"field-tue-relative+-1": "last Tuesday",
	"field-minute-short": "Minute",
	"field-week-narrow@localeAlias248": {
		"bundle": "",
		"target": "field-week-short"
	},
	"field-week-narrow@localeAlias249": {
		"bundle": "",
		"target": "field-week"
	},
	"field-era-narrow@localeAlias236": {
		"bundle": "",
		"target": "field-era-short"
	},
	"field-era-narrow@localeAlias237": {
		"bundle": "",
		"target": "field-era"
	},
	"dateFormatItem-Hm": "HH:mm",
	"field-weekday-narrow@localeAlias260": {
		"bundle": "",
		"target": "field-weekday-short"
	},
	"field-weekday-narrow@localeAlias261": {
		"bundle": "",
		"target": "field-weekday"
	},
	"field-week-relative+0": "this week",
	"field-week-relative+1": "next week",
	"dateFormatItem-MMM": "LLL",
	"field-sun-relative+0": "this Sunday",
	"field-sun-relative+1": "next Sunday",
	"months-format-narrow@localeAlias201": {
		"bundle": "coptic",
		"target": "months-standAlone-narrow"
	},
	"field-sat-narrow-relative+-1": "last Saturday",
	"dateTimeFormats-appendItem-Month": "{0} ({2}: {1})",
	"quarters-standAlone-abbr": [
		"Q1",
		"Q2",
		"Q3",
		"Q4"
	],
	"quarters-standAlone-abbr@localeAlias219": {
		"bundle": "gregorian",
		"target": "quarters-format-abbr"
	},
	"field-fri-short@localeAlias280": {
		"bundle": "",
		"target": "field-fri"
	},
	"field-thu-narrow@localeAlias278": {
		"bundle": "",
		"target": "field-thu-short"
	},
	"field-thu-narrow@localeAlias279": {
		"bundle": "",
		"target": "field-thu"
	},
	"field-month-short-relative+-1": "last month",
	"field-hour-narrow@localeAlias290": {
		"bundle": "",
		"target": "field-hour-short"
	},
	"dateFormatItem-EHms": "E HH:mm:ss",
	"field-hour-narrow@localeAlias291": {
		"bundle": "",
		"target": "field-hour"
	},
	"dateFormatItem-MMMMd": "MMMM d",
	"eraNarrow@localeAlias231": {
		"bundle": "coptic",
		"target": "eraAbbr"
	},
	"field-week": "Week",
	"field-day-narrow": "Day",
	"field-hour-narrow-relative+0": "this hour"
}
//end v1.x content
,
	"ar": true,
	"cs": true,
	"da": true,
	"de": true,
	"el": true,
	"es": true,
	"fi": true,
	"fr": true,
	"he": true,
	"hu": true,
	"ja": true,
	"ko": true,
	"mk": true,
	"nb": true,
	"nl": true,
	"pl": true,
	"ro": true,
	"ru": true,
	"sk": true,
	"sr": true,
	"sv": true,
	"th": true,
	"tr": true,
	"zh": true,
	"zh-hant": true
});